pygeodesy.triaxials.triaxial3.BetOmgAlp5Tuple

Package pygeodesy :: Package triaxials :: Module triaxial3 :: Class BetOmgAlp5Tuple |
[frames] | no frames]

# Class BetOmgAlp5Tuple

       object --+
                |
            tuple --+
                    |
       object --+   |
                |   |
     named._Named --+
                    |
    named._NamedTuple --+
                        |
        angles._Ang3Tuple --+
                            |
                           BetOmgAlp5Tuple

5-Tuple `(bet, omg, alp, h, llk)` with ellipsoidal lat- `bet`, longitude `omg` and azimuth `alp`, all in Angles on and height `h` off the triaxial's surface and kind `llk` set to `LLK.ELLIPSOIDAL`.

Instance Methods
Inherited from `angles._Ang3Tuple`: `toDegrees`, `toLambertian`, `toRadians`, `toUnit` Inherited from `named._NamedTuple`: `__delattr__`, `__getattr__`, `__hash__`, `__repr__`, `__setattr__`, `__str__`, `dup`, `items`, `iteritems`, `iterunits`, `reUnit`, `toRepr`, `toStr`, `toUnits`, `units` Inherited from `tuple`: `__add__`, `__contains__`, `__eq__`, `__ge__`, `__getattribute__`, `__getitem__`, `__getnewargs__`, `__getslice__`, `__gt__`, `__iter__`, `__le__`, `__len__`, `__lt__`, `__mul__`, `__ne__`, `__rmul__`, `count`, `index` Inherited from `named._Named`: `__format__`, `__imatmul__`, `__matmul__`, `__rmatmul__`, `attrs`, `classof`, `copy`, `methodname`, `rename`, `renamed`, `toStr2` Inherited from `object`: `__init__`, `__reduce__`, `__reduce_ex__`, `__sizeof__`, `__subclasshook__`

Static Methods
Inherited from `named._NamedTuple`: `__new__`

Properties
Inherited from `named._Named`: `classname`, `classnaming`, `iteration`, `name`, `named`, `named2`, `named3`, `named4`, `sizeof`, `typename` Inherited from `object`: `__class__`